## 1.4.0 (2023-09-12)

### Feat

- Added async cursor pagination support

## 1.3.0 (2023-04-29)

### Feat

- Added row numbers to example list

### Refactor

- Removed unused code
- Removed first item check, it's not needed

## 1.2.0 (2023-04-16)

### Feat

- Added example with values_list
- Added pagination using values_list

## 1.1.3 (2023-04-08)

### Fix

- Don't throw exception on unknown page

## 1.1.2 (2023-02-11)

## 1.1.1 (2023-02-11)

### Refactor

- Better url pattern converter

## 1.1.0 (2023-02-11)

### Feat

- Implemented datetime serialization
- Implemented date serialization
- Implemented time serialization
- Added decimal number serialization with decimal places
- Added whole decimal serialization
- Implemented long number serialization
- Better integer tests
- Added float serialization
- Implemented number serialization
- Added string fallback
- Added byte serialization
- Added string serialization
- Added boolean serialization
- Implemented deserialization
- Added support for new serialization
- Match sentinel inside of database

### Fix

- Fixed packing long numbers
- Fixed string deserialization

### Refactor

- Replaced serialization method
- Preparing to decimal serialization
- Better text tests
- Better string serialization
- Using loop without break
- Using big endian (network)

## 1.0.2 (2022-12-26)

### Fix

- Fixed comparing to date fields
- Suppress setuptools warnings

## 1.0.1 (2022-12-19)

### Fix

- Fixed link to page.html
- Replaced wrong links

## 1.0.0 (2022-12-18)

### Feat

- Added example cursor pagination
- Added model data to sample project
- Added CursorPageConverter
- Added template tests
- Added pylint configuration
- Using unicode ellipsis
- Added CursorPaginateMixin
- Added paginate_by tests
- Added paginate_cursor_queryset shortcut
- Added implicitly ordered model test
- Added get_order_by function to retrieve queryset ordering
- More order_by tests
- Added condition table
- Sorting NULLs, WIP
- Added tests for invert_order_by
- Added tests for url key encoder / decoder
- Updated .gitignore
- Added pre-commit hook
- Added tests infrastructure
- Implemented cursor navigation
- Added utility functions for cursor navigation
- Export page_range directly to template
- Added .gitignore

### Fix

- Fixed urlsafe pattern matching
- Updated sample project
- Ugly, but it works
- Fixed repeaded line ends

### Refactor

- Migrated to pyproject.toml
- Removed unused code, simplefied
- Cleanup old imports
- Replaced hardcoded string with constant
- Renamed settings to match django get_elided_page_range
- Replaced my ranges calculation with internal

## 0.2 (2017-04-05)

## 0.1 (2017-04-05)
